==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/PAYBYMETHOD.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORDERTERMID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="ordertermtype" type="{http://schemas.datastream.net/MP_fields}ORDERTERMTYPE_Type" fixed="PYMT" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "ordertermid"
})
@XmlRootElement(name = "PAYBYMETHOD")
public class PAYBYMETHOD {

    @XmlElement(name = "ORDERTERMID", required = true)
    protected ORDERTERMID_Type ordertermid;
    @XmlAttribute(name = "ordertermtype")
    protected ORDERTERMTYPE_Type ordertermtype;

    /**
     * Obtient la valeur de la propriété ordertermid.
     * 
     * @return
     *     possible object is
     *     {@link ORDERTERMID_Type }
     *     
     */
    public ORDERTERMID_Type getORDERTERMID() {
        return ordertermid;
    }

    /**
     * Définit la valeur de la propriété ordertermid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORDERTERMID_Type }
     *     
     */
    public void setORDERTERMID(ORDERTERMID_Type value) {
        this.ordertermid = value;
    }

    /**
     * Obtient la valeur de la propriété ordertermtype.
     * 
     * @return
     *     possible object is
     *     {@link ORDERTERMTYPE_Type }
     *     
     */
    public ORDERTERMTYPE_Type getOrdertermtype() {
        if (ordertermtype == null) {
            return ORDERTERMTYPE_Type.PYMT;
        } else {
            return ordertermtype;
        }
    }

    /**
     * Définit la valeur de la propriété ordertermtype.
     * 
     * @param value
     *     allowed object is
     *     {@link ORDERTERMTYPE_Type }
     *     
     */
    public void setOrdertermtype(ORDERTERMTYPE_Type value) {
        this.ordertermtype = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/PAYBYMETHOD.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORDERTERMID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="ordertermtype" type="{http://schemas.datastream.net/MP_fields}ORDERTERMTYPE_Type" fixed="PYMT" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "ordertermid"
})
@XmlRootElement(name = "PAYBYMETHOD")
public class PAYBYMETHOD {

    @XmlElement(name = "ORDERTERMID", required = true)
    protected ORDERTERMID_Type ordertermid;
    @XmlAttribute(name = "ordertermtype")
    protected ORDERTERMTYPE_Type ordertermtype;

    /**
     * Gets the value of the ordertermid property.
     * 
     * @return
     *     possible object is
     *     {@link ORDERTERMID_Type }
     *     
     */
    public ORDERTERMID_Type getORDERTERMID() {
        return ordertermid;
    }

    /**
     * Sets the value of the ordertermid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORDERTERMID_Type }
     *     
     */
    public void setORDERTERMID(ORDERTERMID_Type value) {
        this.ordertermid = value;
    }

    /**
     * Gets the value of the ordertermtype property.
     * 
     * @return
     *     possible object is
     *     {@link ORDERTERMTYPE_Type }
     *     
     */
    public ORDERTERMTYPE_Type getOrdertermtype() {
        if (ordertermtype == null) {
            return ORDERTERMTYPE_Type.PYMT;
        } else {
            return ordertermtype;
        }
    }

    /**
     * Sets the value of the ordertermtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORDERTERMTYPE_Type }
     *     
     */
    public void setOrdertermtype(ORDERTERMTYPE_Type value) {
        this.ordertermtype = value;
    }

}
